@@ -8,42 +8,42 @@ var NAVTREEINDEX0 =
 "audio-dsp-filter_8c-example.html":[13,8],
 "audio-dsp-src_8c-example.html":[13,7],
 "audio-src_8c-example.html":[13,6],
-"audio_2raw_8h.html":[10,8,7,4],
+"audio_2raw-types_8h.html":[10,8,7,4],
+"audio_2raw_8h.html":[10,8,7,5],
 "audio_8h.html":[10,8,7,6],
 "bluez-session_8c-example.html":[13,23],
 "buffer_2buffer_8h.html":[10,8,1,1],
 "buffer_2type-info_8h.html":[10,8,1,3],
-"buffers_8h.html":[10,5,9,0],
+"buffers-types_8h.html":[10,8,7,8],
 "builder_8h.html":[10,8,0,0],
-"chroma_8h.html":[10,8,7,12],
+"chroma_8h.html":[10,8,7,24],
 "classes.html":[11,1],
 "client-node_8h.html":[10,7,0,0],
 "client_8h.html":[10,4,3,0],
-"color_8h.html":[10,8,7,13],
+"color_8h.html":[10,8,7,25],
 "compare_8h.html":[10,8,0,2],
 "conf_8h.html":[10,6,1,0],
-"context_8h.html":[10,4,2,0],
 "control_2type-info_8h.html":[10,8,2,1],
-"core_8h.html":[10,4,4,0],
 "core_8h.html":[10,4,14,0],
+"core_8h.html":[10,4,4,0],
 "cpu_8h.html":[10,8,9,0,0],
 "data-loop_8h.html":[10,5,11,0],
 "dbus_8h.html":[10,8,9,1,0],
 "debug_2buffer_8h.html":[10,8,3,0],
-"debug_2dict_8h.html":[10,8,3,1],
-"debug_2format_8h.html":[10,8,3,2],
-"debug_2pod_8h.html":[10,8,3,6],
+"debug_2dict_8h.html":[10,8,3,2],
+"debug_2format_8h.html":[10,8,3,3],
+"debug_2pod_8h.html":[10,8,3,7],
 "defs_8h.html":[10,8,8,1,0],
 "dsd_8h.html":[10,8,7,0],
-"encoded_8h.html":[10,8,7,14],
 "examples.html":[13],
 "export-sink_8c-example.html":[13,19],
 "export-source_8c-example.html":[13,20],
 "export-spa-device_8c-example.html":[13,22],
 "export-spa_8c-example.html":[13,21],
 "factory_8h.html":[10,4,6,0],
-"functions.html":[11,2,0],
+"format-types_8h.html":[10,8,7,10],
 "functions.html":[11,2,0,0],
+"functions.html":[11,2,0],
 "functions_a.html":[11,2,0,1],
 "functions_b.html":[11,2,0,2],
 "functions_c.html":[11,2,0,3],
@@ -66,8 +66,8 @@ var NAVTREEINDEX0 =
 "functions_t.html":[11,2,0,20],
 "functions_u.html":[11,2,0,21],
 "functions_v.html":[11,2,0,22],
-"functions_vars.html":[11,2,1,0],
 "functions_vars.html":[11,2,1],
+"functions_vars.html":[11,2,1,0],
 "functions_vars_a.html":[11,2,1,1],
 "functions_vars_b.html":[11,2,1,2],
 "functions_vars_c.html":[11,2,1,3],
@@ -105,8 +105,8 @@ var NAVTREEINDEX0 =
 "globals_b.html":[12,0,2],
 "globals_c.html":[12,0,3],
 "globals_d.html":[12,0,4],
-"globals_defs.html":[12,6,0],
 "globals_defs.html":[12,6],
+"globals_defs.html":[12,6,0],
 "globals_defs_a.html":[12,6,1],
 "globals_defs_b.html":[12,6,2],
 "globals_defs_c.html":[12,6,3],
@@ -131,8 +131,8 @@ var NAVTREEINDEX0 =
 "globals_defs_z.html":[12,6,22],
 "globals_e.html":[12,0,5],
 "globals_enum.html":[12,4],
-"globals_eval.html":[12,5],
 "globals_eval.html":[12,5,0],
+"globals_eval.html":[12,5],
 "globals_eval_a.html":[12,5,1],
 "globals_eval_b.html":[12,5,2],
 "globals_eval_c.html":[12,5,3],
@@ -149,8 +149,8 @@ var NAVTREEINDEX0 =
 "globals_eval_t.html":[12,5,14],
 "globals_eval_v.html":[12,5,15],
 "globals_f.html":[12,0,6],
-"globals_func.html":[12,1,0],
 "globals_func.html":[12,1],
+"globals_func.html":[12,1,0],
 "globals_func_a.html":[12,1,1],
 "globals_func_b.html":[12,1,2],
 "globals_func_c.html":[12,1,3],
