@@ -1,5 +1,80 @@
 var NAVTREEINDEX18 =
 {
+"structpw__impl__node.html":[10,5,7,2],
+"structpw__impl__node__events.html":[10,5,7,1],
+"structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18":[10,5,7,1,16],
+"structpw__impl__node__events.html#a16b71cb7eece2a1b7b2d89007357238b":[10,5,7,1,10],
+"structpw__impl__node__events.html#a21b4486448a26b56eea0508a92c99035":[10,5,7,1,1],
+"structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6":[10,5,7,1,4],
+"structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f":[10,5,7,1,15],
+"structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463":[10,5,7,1,12],
+"structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430":[10,5,7,1,0],
+"structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a":[10,5,7,1,2],
+"structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7":[10,5,7,1,8],
+"structpw__impl__node__events.html#a8a7823893c92e2d190c14aa220b71be8":[10,5,7,1,9],
+"structpw__impl__node__events.html#a8aa906ff5f65e321b1e500979cd1d748":[10,5,7,1,6],
+"structpw__impl__node__events.html#a912be8dba73d32a813f2a00576384fa3":[10,5,7,1,13],
+"structpw__impl__node__events.html#a9b2f9b0790584b2ee32e0ee46d9e0c5e":[10,5,7,1,7],
+"structpw__impl__node__events.html#aaf15bbdebaa2b67dd31ba4c3d56cebc6":[10,5,7,1,5],
+"structpw__impl__node__events.html#abae73b060850e69368efdace5e1ddd68":[10,5,7,1,3],
+"structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e":[10,5,7,1,14],
+"structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12":[10,5,7,1,11],
+"structpw__impl__port.html":[10,5,4,3],
+"structpw__impl__port.html":[10,5,7,3],
+"structpw__impl__port.html":[10,5,8,2],
+"structpw__impl__port__events.html":[10,5,8,1],
+"structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[10,5,8,1,8],
+"structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325":[10,5,8,1,1],
+"structpw__impl__port__events.html#a69e18fd1facb78dbb42025c17ef0884a":[10,5,8,1,4],
+"structpw__impl__port__events.html#a7049ef85f5a0f35988c6a2f60a02c385":[10,5,8,1,2],
+"structpw__impl__port__events.html#a73104e5c2b8f887977945a597fa6b1ee":[10,5,8,1,5],
+"structpw__impl__port__events.html#a74130c25a3cc6e05ef753847e17a85cb":[10,5,8,1,11],
+"structpw__impl__port__events.html#a77a67b128bc4961a1caa38572f8f6094":[10,5,8,1,7],
+"structpw__impl__port__events.html#a7d76d0a7bef38963ff7c3e5a4fd9a1d3":[10,5,8,1,0],
+"structpw__impl__port__events.html#a8d5a42f37e97b448cf6e1d7942677c81":[10,5,8,1,10],
+"structpw__impl__port__events.html#a8ddfb5c4f95dafcf15e0e9d3df367169":[10,5,8,1,3],
+"structpw__impl__port__events.html#a9f23250e31672a49aa26a5dd5b593e80":[10,5,8,1,9],
+"structpw__impl__port__events.html#acae053d6b84259d9a475eda14ca670ed":[10,5,8,1,6],
+"structpw__link.html":[10,4,7,4],
+"structpw__link__events.html":[10,4,7,2],
+"structpw__link__events.html#a36fd833d967b2b648424449197eb95c5":[10,4,7,2,0],
+"structpw__link__events.html#a4f9f823d13092e197c89c151ea21b27b":[10,4,7,2,1],
+"structpw__link__info.html":[10,4,7,1],
+"structpw__link__info.html#a0513f644f43b252a0e068e09c8452382":[10,4,7,1,2],
+"structpw__link__info.html#a0c7b378ed65b5311702cd2b693d6b819":[10,4,7,1,0],
+"structpw__link__info.html#a274785180186fbe127e48715092d775a":[10,4,7,1,5],
+"structpw__link__info.html#a5a21130d91e20dafc4ce1b09b7c30aca":[10,4,7,1,1],
+"structpw__link__info.html#a64ff3f8d01d62e5e2ed86933fd6b15e1":[10,4,7,1,6],
+"structpw__link__info.html#a98d810a2a69da694add77f70b2f86061":[10,4,7,1,7],
+"structpw__link__info.html#ad4e7766ec44b62455169b916c3cdbbb1":[10,4,7,1,3],
+"structpw__link__info.html#ae62f88ba3c96b5465a0b046ce93acdd5":[10,4,7,1,8],
+"structpw__link__info.html#afaa2ba4fad6933cc019375c14f103120":[10,4,7,1,4],
+"structpw__link__methods.html":[10,4,7,3],
+"structpw__link__methods.html#a93094b3a43a3dd5911e6016f1cbd44cf":[10,4,7,3,0],
+"structpw__link__methods.html#ae0864a9eb97073db8174b051b074f180":[10,4,7,3,1],
+"structpw__loop.html":[10,4,8,1],
+"structpw__loop.html#a4624741580712c167c17bd9242be003f":[10,4,8,1,1],
+"structpw__loop.html#a639de0bfd74cf9e292932aaed15182c5":[10,4,8,1,2],
+"structpw__loop.html#abab71679705176a16c9e27b3115701c3":[10,4,8,1,0],
+"structpw__main__loop.html":[10,4,1,2],
+"structpw__main__loop__events.html":[10,4,1,1],
+"structpw__main__loop__events.html#a1713b16265dcafb5944612c5d653a553":[10,4,1,1,1],
+"structpw__main__loop__events.html#abbfcaf5cd47f231f25979949df15cf29":[10,4,1,1,0],
+"structpw__map.html":[10,6,4,1],
+"structpw__map.html#a6fc621171dbc57de8c44d26f639d2f1b":[10,6,4,1,0],
+"structpw__map.html#acf2ad4417afa20b00e4a1f3837573d87":[10,6,4,1,1],
+"structpw__map__range.html":[10,6,5,5],
+"structpw__map__range.html#a96ecc91bdc991ce5c807a1b79aded4f4":[10,6,5,5,1],
+"structpw__map__range.html#aaf1ff0e5b8623a1c64ee4ac9dbf2008a":[10,6,5,5,0],
+"structpw__memblock.html":[10,6,5,2],
+"structpw__memblock.html#a1ca99934939d8b89c158a0256d6d906c":[10,6,5,2,1],
+"structpw__memblock.html#a4731883fd9899d0d668c0f44a16d3b33":[10,6,5,2,5],
+"structpw__memblock.html#a66508184497a6f6e211eafa8f6e4edd7":[10,6,5,2,0],
+"structpw__memblock.html#a88d9c260a71ebd2413b9c4f6c6b84889":[10,6,5,2,3],
+"structpw__memblock.html#a8e96a2d24a5fc723b2a637de4bf700b1":[10,6,5,2,6],
+"structpw__memblock.html#a8fb4076dc9a00af2a3da6be6859b6a00":[10,6,5,2,4],
+"structpw__memblock.html#ac130234986a5d662d20a3e593448bbbd":[10,6,5,2,2],
+"structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515":[10,6,5,2,7],
 "structpw__memchunk.html":[10,6,5,6],
 "structpw__memmap.html":[10,6,5,3],
 "structpw__memmap.html#a2a254ea08d19704537d73b68ef548a12":[10,6,5,3,3],
@@ -174,80 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[10,7,4,10,0],
 "structpw__session__info.html":[10,7,4,18],
 "structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[10,7,4,18,3],
-"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2],
-"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
-"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0],
-"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
-"structpw__session__methods.html":[10,7,4,11],
-"structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[10,7,4,11,0],
-"structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f":[10,7,4,11,4],
-"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0":[10,7,4,11,2],
-"structpw__session__methods.html#a9311ff4c5e45bce0b1a56ee64e720b09":[10,7,4,11,3],
-"structpw__session__methods.html#afeb231bfac6c5539d258eb06b22e0acf":[10,7,4,11,1],
-"structpw__stream.html":[10,0,5],
-"structpw__stream__control.html":[10,0,2],
-"structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1":[10,0,2,3],
-"structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2":[10,0,2,0],
-"structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1":[10,0,2,1],
-"structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046":[10,0,2,6],
-"structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62":[10,0,2,2],
-"structpw__stream__control.html#a925311b76a91a9034391da7343865091":[10,0,2,5],
-"structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5":[10,0,2,4],
-"structpw__stream__events.html":[10,0,4],
-"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[10,0,4,7],
-"structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[10,0,4,3],
-"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02":[10,0,4,11],
-"structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3":[10,0,4,5],
-"structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b":[10,0,4,8],
-"structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c":[10,0,4,10],
-"structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419":[10,0,4,0],
-"structpw__stream__events.html#a89192aed5fcd89314bf7cc7ef6b21085":[10,0,4,2],
-"structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042":[10,0,4,9],
-"structpw__stream__events.html#abbe98bb0d78e6411d08244495f349b0b":[10,0,4,1],
-"structpw__stream__events.html#abd09d7c76b0e14a201a438f09e609b29":[10,0,4,6],
-"structpw__stream__events.html#ad60b819ff0ea17b0bd8833220cbd4a3e":[10,0,4,4],
-"structpw__thread__loop.html":[10,5,15,2],
-"structpw__thread__loop__events.html":[10,5,15,1],
-"structpw__thread__loop__events.html#a3c806806a4d07a0b3735f4b625740652":[10,5,15,1,1],
-"structpw__thread__loop__events.html#a6815fa728af5ab602c111e7c5b680387":[10,5,15,1,0],
-"structpw__time.html":[10,0,3],
-"structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7":[10,0,3,3],
-"structpw__time.html#a41d793c390eefc6aee165e16e0d7c898":[10,0,3,1],
-"structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff":[10,0,3,5],
-"structpw__time.html#a91dafbb38397328f8705e2bb20b7625a":[10,0,3,4],
-"structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d":[10,0,3,6],
-"structpw__time.html#a99e3d7963e24fbf410afa03c73465328":[10,0,3,2],
-"structpw__time.html#ad817da21bea1591d70f837c251a73468":[10,0,3,0],
-"structpw__time.html#aebd42745267531bc23e1ee34dd759607":[10,0,3,7],
-"structpw__work__queue.html":[10,5,16,1],
-"structpwtest__context.html":[10,2,2],
-"structpwtest__spa__plugin.html":[10,2,1],
-"structpwtest__spa__plugin.html#a22553184b5d864e926e17d976cffca9f":[10,2,1,2],
-"structpwtest__spa__plugin.html#a8bb79b9b0e5cb045fa2686edde9c3d34":[10,2,1,5],
-"structpwtest__spa__plugin.html#ad517984d1206a29ad28eb83f19f41dbe":[10,2,1,0],
-"structpwtest__spa__plugin.html#adc8a853d256b3dca56a3e805dc96c5b4":[10,2,1,3],
-"structpwtest__spa__plugin.html#ae819473de8479871a6cd78f10a97ce68":[10,2,1,1],
-"structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406":[10,2,1,4],
-"structpwtest__suite.html":[10,2,3],
-"structpwtest__test.html":[10,2,4],
-"structspa__audio__aec.html":[11,0,137],
-"structspa__audio__aec.html#a09e1e6ddb6cba06861e418fad8eb2442":[11,0,137,1],
-"structspa__audio__aec.html#a2c343b0ced8bc8a9d22c441558c1cc9f":[11,0,137,2],
-"structspa__audio__aec.html#a472c09f9a147170d0892a650b60c9b5d":[11,0,137,0],
-"structspa__audio__aec__events.html":[11,0,138],
-"structspa__audio__aec__events.html#a355f3bedb9b4094912577187225797d9":[11,0,138,1],
-"structspa__audio__aec__events.html#ab137f922d3a547caf388c5c11be2e5ce":[11,0,138,0],
-"structspa__audio__aec__info.html":[11,0,139],
-"structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[11,0,139,0],
-"structspa__audio__aec__methods.html":[11,0,140],
-"structspa__audio__aec__methods.html#a028adaf84c4fb5c19e416c53874ad57f":[11,0,140,8],
-"structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[11,0,140,1],
-"structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,140,4],
-"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,140,6],
-"structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,140,5],
-"structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8":[11,0,140,7],
-"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,140,3],
-"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,140,0],
-"structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,140,9],
-"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2]
+"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2]
 };
